==> seplib-6.3.5.tar.gz: seplib-6.3.5/seplib_base/lib/corelibs/superset/drn.c <==
#define SET_SDOC 1
/*
-------------------------------------------------

Author: Robert Clapp, ESMB 463, 7230253

Date Created:Sun Aug 16 15:04:02 PDT 1998

Purpose: 

*/	 

#include "../include/superset_internal.h"
#include <superset.h> 


/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*
<
sep3d_set_drn

USAGE
ierr= sep3d_set_drn(char *sep3dname,  int *drn)

INPUT PARAMETERS
sep3dname -  char*   tag associated with sep3d structure

OUTPUT PARAMETERS
drn       -  int*    data record number for the dataset

RETURN VALUES
0   =  if it works correctly
(check superset.h for other return values and there meaning)

DESCRIPTION
Set the data record number for the headers currently in memory
>
*/


#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_set_drn(char *sep3dname,int *drn)
_XFUNCPROTOEND
#else
int sep3d_set_drn(sep3dname, drn)
char *sep3dname;
int *drn;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE);  /* get info on this tag */
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));


if(info->drn!=SEPNULL) free(info->drn);
if(info->nh==0) return(sepwarn(NOT_MET,
	"size of headers (sep3d_set_nh) must be called before sep3d_set_drn  (%s)\n",
	sep3dname));

info->drn=(int*)alloc(sizeof(int)*info->nh);
for(i1=0; i1 < info->nh; i1++)info->drn[i1]=drn[i1];
return(SUCCESS);
}

/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*
<
sep3d_grab_drn

USAGE
ierr= sep3d_grab_drn(char *sep3dname,  int *drn)

INPUT PARAMETERS
sep3dname -  char*   tag associated with sep3d structure

OUTPUT PARAMETERS
drn       -  int*    data record number for the dataset

RETURN VALUES
0   =  if it works correctly
(check superset.h for other return values and there meaning)

DESCRIPTION
Find the data record number of the dataset
>
*/


#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_grab_inorder(char *sep3dname,int *inorder)
_XFUNCPROTOEND
#else
int sep3d_grab_inorder(sep3dname, inorder)
char *sep3dname;
int *inorder;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE);  /* get info on this tag */
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));

*inorder=info->in_order;
return(SUCCESS);
}




#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_grab_drn(char *sep3dname,int *drn)
_XFUNCPROTOEND
#else
int sep3d_grab_drn(sep3dname, drn)
char *sep3dname;
int *drn;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE);  /* get info on this tag */
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));


if(info->drn==SEPNULL){
	sep3d_print(info);
	return(sepwarn(NOT_MET,"drn has not been set in %s\n",sep3dname));
}
for(i1=0; i1 < info->nh; i1++) drn[i1]=info->drn[i1];
return(SUCCESS);
}




/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*
<
sep3d_drn_set

USAGE
ierr= sep3d_drn_set(char *sep3dname)

INPUT PARAMETERS
sep3dname -  char*   tag associated with sep3d structure


RETURN VALUES
0   =  if drn is set to reasonable values

-1  =  drn not set to reasonable values


DESCRIPTION
Sets that the dataset is in order
>
*/

#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_drn_set(char *sep3dname)
_XFUNCPROTOEND
#else
int sep3d_drn_set(sep3dname)
char *sep3dname;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE); 
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));
if(info->in_order==1) return(-1);

if(info->drn == SEPNULL) return(-1);
for(i1=0; i1 < info->nh; i1++){
   if(info->drn[i1] < 1) return(-1);
}
return(SUCCESS);
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*
<
sep3d_set_inorder

USAGE
ierr= sep3d_set_inorder(char *sep3dname)

INPUT PARAMETERS
sep3dname -  char*   tag associated with sep3d structure


RETURN VALUES
0   =  if it works correctly
(check superset.h for other return values and there meaning)

DESCRIPTION
Sets that the dataset is in order
>
*/

#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_set_inorder(char *sep3dname)
_XFUNCPROTOEND
#else
int sep3d_set_inorder(sep3dname)
char *sep3dname;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE); 
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));

info->in_order=1;
if(info->drn != SEPNULL){
	 free(info->drn);
	 info->drn=SEPNULL;
}

return(SUCCESS);
}

==> seplib-6.3.9.tar.gz: seplib-6.3.9/seplib_base/lib/corelibs/superset/drn.c <==
#define SET_SDOC 1
/*
-------------------------------------------------

Author: Robert Clapp, ESMB 463, 7230253

Date Created:Sun Aug 16 15:04:02 PDT 1998

Purpose: 

*/	 

#include "superset_internal.h"
#include <superset.h> 


/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*
<
sep3d_set_drn

USAGE
ierr= sep3d_set_drn(char *sep3dname,  int *drn)

INPUT PARAMETERS
sep3dname -  char*   tag associated with sep3d structure

OUTPUT PARAMETERS
drn       -  int*    data record number for the dataset

RETURN VALUES
0   =  if it works correctly
(check superset.h for other return values and there meaning)

DESCRIPTION
Set the data record number for the headers currently in memory
>
*/


#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_set_drn(char *sep3dname,int *drn)
_XFUNCPROTOEND
#else
int sep3d_set_drn(sep3dname, drn)
char *sep3dname;
int *drn;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE);  /* get info on this tag */
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));


if(info->drn!=SEPNULL) free(info->drn);
if(info->nh==0) return(sepwarn(NOT_MET,
	"size of headers (sep3d_set_nh) must be called before sep3d_set_drn  (%s)\n",
	sep3dname));

info->drn=(int*)alloc(sizeof(int)*info->nh);
for(i1=0; i1 < info->nh; i1++)info->drn[i1]=drn[i1];
return(SUCCESS);
}

/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*
<
sep3d_grab_drn

USAGE
ierr= sep3d_grab_drn(char *sep3dname,  int *drn)

INPUT PARAMETERS
sep3dname -  char*   tag associated with sep3d structure

OUTPUT PARAMETERS
drn       -  int*    data record number for the dataset

RETURN VALUES
0   =  if it works correctly
(check superset.h for other return values and there meaning)

DESCRIPTION
Find the data record number of the dataset
>
*/


#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_grab_inorder(char *sep3dname,int *inorder)
_XFUNCPROTOEND
#else
int sep3d_grab_inorder(sep3dname, inorder)
char *sep3dname;
int *inorder;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE);  /* get info on this tag */
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));

*inorder=info->in_order;
return(SUCCESS);
}




#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_grab_drn(char *sep3dname,int *drn)
_XFUNCPROTOEND
#else
int sep3d_grab_drn(sep3dname, drn)
char *sep3dname;
int *drn;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE);  /* get info on this tag */
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));


if(info->drn==SEPNULL){
	sep3d_print(info);
	return(sepwarn(NOT_MET,"drn has not been set in %s\n",sep3dname));
}
for(i1=0; i1 < info->nh; i1++) drn[i1]=info->drn[i1];
return(SUCCESS);
}




/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*
<
sep3d_drn_set

USAGE
ierr= sep3d_drn_set(char *sep3dname)

INPUT PARAMETERS
sep3dname -  char*   tag associated with sep3d structure


RETURN VALUES
0   =  if drn is set to reasonable values

-1  =  drn not set to reasonable values


DESCRIPTION
Sets that the dataset is in order
>
*/

#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_drn_set(char *sep3dname)
_XFUNCPROTOEND
#else
int sep3d_drn_set(sep3dname)
char *sep3dname;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE); 
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));
if(info->in_order==1) return(-1);

if(info->drn == SEPNULL) return(-1);
for(i1=0; i1 < info->nh; i1++){
   if(info->drn[i1] < 1) return(-1);
}
return(SUCCESS);
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/*
<
sep3d_set_inorder

USAGE
ierr= sep3d_set_inorder(char *sep3dname)

INPUT PARAMETERS
sep3dname -  char*   tag associated with sep3d structure


RETURN VALUES
0   =  if it works correctly
(check superset.h for other return values and there meaning)

DESCRIPTION
Sets that the dataset is in order
>
*/

#if NeedFunctionPrototypes
_XFUNCPROTOBEGIN
int sep3d_set_inorder(char *sep3dname)
_XFUNCPROTOEND
#else
int sep3d_set_inorder(sep3dname)
char *sep3dname;
#endif 
{
int i1,ierr;
sep_3d *info;


info = tag_info_sep3d(sep3dname, INQUIRE); 
if(info == SEPNULL)
  return (sepwarn(INVALID_STRUC,"tag:%s  invalid struc\n",sep3dname));

info->in_order=1;
if(info->drn != SEPNULL){
	 free(info->drn);
	 info->drn=SEPNULL;
}

return(SUCCESS);
}
